;; Generated package description from vc-jj.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "vc-jj" "0.5.0.20260727.66" "VC backend for the Jujutsu version control system" '((emacs "28.1") (compat "30.1") (project "0.11.2")) :commit "17310449644cc527dfa6b8ca5320de4c33d1c7f3" :authors '(("Rudolf Schlatte" . "rudi@constantly.at") ("Kristoffer Balintona" . "krisbalintona@gmail.com")) :maintainer '(("Rudolf Schlatte" . "rudi@constantly.at") ("Kristoffer Balintona" . "krisbalintona@gmail.com")) :keywords '("vc" "tools") :url "https://codeberg.org/emacs-jj-vc/vc-jj.el")
